@@ -11,4 +11,4 @@ def parse_args(subparsers):
 async def _main(args):
     disable_stdout_buffering()
     ebus = create_ebus(args)
-    print(await ebus.get_state())
+    print(await ebus.async_get_state())
